% Auto-generated chapter 39 for abudawud
% Hadiths in this chapter: 60

\hadithdefcmd{abudawud}{4291}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ شَرَاحِيلَ بْنِ يَزِيدَ الْمَعَافِرِيِّ، عَنْ أَبِي عَلْقَمَةَ، عَنْ أَبِي هُرَيْرَةَ، فِيمَا أَعْلَمُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ يَبْعَثُ لِهَذِهِ الأُمَّةِ عَلَى رَأْسِ كُلِّ مِائَةِ سَنَةٍ مَنْ يُجَدِّدُ لَهَا دِينَهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ عَبْدُ الرَّحْمَنِ بْنُ شُرَيْحٍ الإِسْكَنْدَرَانِيُّ لَمْ يَجُزْ بِهِ شَرَاحِيلَ ‏.‏\hadithno{4291}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurayrah: The Prophet (ﷺ) said: Allah will raise for this community at the end of every hundred years the one who will renovate its religion for it. Abu Dawud said: 'Abd al-Rahman bin Shuriah al-Iskandarani has also transmitted this tradition, but he did not exceed Shrahil}}
\hadithdefcmd{abudawud}{4292}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ حَسَّانَ بْنِ عَطِيَّةَ، قَالَ مَالَ مَكْحُولٌ وَابْنُ أَبِي زَكَرِيَّا إِلَى خَالِدِ بْنِ مَعْدَانَ وَمِلْتُ مَعَهُمْ فَحَدَّثَنَا عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنِ الْهُدْنَةِ، قَالَ قَالَ جُبَيْرٌ انْطَلِقْ بِنَا إِلَى ذِي مِخْبَرٍ - رَجُلٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم - فَأَتَيْنَاهُ فَسَأَلَهُ جُبَيْرٌ عَنِ الْهُدْنَةِ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ سَتُصَالِحُونَ الرُّومَ صُلْحًا آمِنًا فَتَغْزُونَ أَنْتُمْ وَهُمْ عَدُوًّا مِنْ وَرَائِكُمْ فَتُنْصَرُونَ وَتَغْنَمُونَ وَتَسْلَمُونَ ثُمَّ تَرْجِعُونَ حَتَّى تَنْزِلُوا بِمَرْجٍ ذِي تُلُولٍ فَيَرْفَعُ رَجُلٌ مِنْ أَهْلِ النَّصْرَانِيَّةِ الصَّلِيبَ فَيَقُولُ غَلَبَ الصَّلِيبُ فَيَغْضَبُ رَجُلٌ مِنَ الْمُسْلِمِينَ فَيَدُقُّهُ فَعِنْدَ ذَلِكَ تَغْدِرُ الرُّومُ وَتَجْمَعُ لِلْمَلْحَمَةِ ‏"‏ ‏.‏\hadithno{4292}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Dhu Mikhbar said:I heard the Messenger of Allah (ﷺ) say: you will make a secure peace with the Byzantines, then you and they will fight an enemy behind you, and you will be victorious, take booty, and be safe. You will then return and alight in a meadow with mounds and one of the Christians will raise the cross and say: The cross has conquered. One of the Muslims will become angry and smash it, and the Byzantines will act treacherously and prepare for the battle}}
\hadithdefcmd{abudawud}{4293}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ الْحَرَّانِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا أَبُو عَمْرٍو، عَنْ حَسَّانَ بْنِ عَطِيَّةَ، بِهَذَا الْحَدِيثِ زَادَ فِيهِ ‏ "‏ وَيَثُورُ الْمُسْلِمُونَ إِلَى أَسْلِحَتِهِمْ فَيَقْتَتِلُونَ فَيُكْرِمُ اللَّهُ تِلْكَ الْعِصَابَةَ بِالشَّهَادَةِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ إِلاَّ أَنَّ الْوَلِيدَ جَعَلَ الْحَدِيثَ عَنْ جُبَيْرٍ عَنْ ذِي مِخْبَرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ رَوْحٌ وَيَحْيَى بْنُ حَمْزَةَ وَبِشْرُ بْنُ بَكْرٍ عَنِ الأَوْزَاعِيِّ كَمَا قَالَ عِيسَى ‏.‏\hadithno{4293}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Hassan b. ’Atiyyah through a different chain of narrators. This version add:The Muslims will then make for their weapons and will fight, and Allah will honor that body with martryrdom. Abu Dawud said: But al-Walid has narrated this tradition from Dhu Mikhbar from the Prophet (ﷺ). Abu Dawud said: Rawh, Yahya bin Hamzah and Bishr bin Bakr has also transmitted it from al-Awza'i as mentioned by 'Isa}}
\hadithdefcmd{abudawud}{4294}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ ثَابِتِ بْنِ ثَوْبَانَ، عَنْ أَبِيهِ، عَنْ مَكْحُولٍ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ مَالِكِ بْنِ يُخَامِرَ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عُمْرَانُ بَيْتِ الْمَقْدِسِ خَرَابُ يَثْرِبَ وَخَرَابُ يَثْرِبَ خُرُوجُ الْمَلْحَمَةِ وَخُرُوجُ الْمَلْحَمَةِ فَتْحُ قُسْطَنْطِينِيَّةَ وَفَتْحُ الْقُسْطَنْطِينِيَّةِ خُرُوجُ الدَّجَّالِ ‏"‏ ‏.‏ ثُمَّ ضَرَبَ بِيَدِهِ عَلَى فَخِذِ الَّذِي حَدَّثَ - أَوْ مَنْكِبِهِ - ثُمَّ قَالَ إِنَّ هَذَا لَحَقٌّ كَمَا أَنَّكَ هَا هُنَا أَوْ كَمَا أَنَّكَ قَاعِدٌ ‏.‏ يَعْنِي مُعَاذَ بْنَ جَبَلٍ ‏.‏\hadithno{4294}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Mu'adh ibn Jabal: The Prophet (ﷺ) said: The flourishing state of Jerusalem will be when Yathrib is in ruins, the ruined state of Yathrib will be when the great war comes, the outbreak of the great war will be at the conquest of Constantinople and the conquest of Constantinople when the Dajjal (Antichrist) comes forth. He (the Prophet) struck his thigh or his shoulder with his hand and said: This is as true as you are here or as you are sitting (meaning Mu'adh ibn Jabal)}}
\hadithdefcmd{abudawud}{4295}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ أَبِي بَكْرِ بْنِ أَبِي مَرْيَمَ، عَنِ الْوَلِيدِ بْنِ سُفْيَانَ الْغَسَّانِيِّ، عَنْ يَزِيدَ بْنِ قُتَيْبٍ السَّكُونِيِّ، عَنْ أَبِي بَحْرِيَّةَ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَلْحَمَةُ الْكُبْرَى وَفَتْحُ الْقُسْطَنْطِينِيَّةِ وَخُرُوجُ الدَّجَّالِ فِي سَبْعَةِ أَشْهُرٍ ‏"‏ ‏.‏\hadithno{4295}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'adh ibn Jabal: The Prophet (ﷺ) said: The greatest war, the conquest of Constantinople and the coming forth of the Dajjal (Antichrist) will take place within a period of seven months}}
\hadithdefcmd{abudawud}{4296}{حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ، عَنْ بَحِيرٍ، عَنْ خَالِدٍ، عَنِ ابْنِ أَبِي بِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَ الْمَلْحَمَةِ وَفَتْحِ الْمَدِينَةِ سِتُّ سِنِينَ وَيَخْرُجُ الْمَسِيحُ الدَّجَّالُ فِي السَّابِعَةِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا أَصَحُّ مِنْ حَدِيثِ عِيسَى ‏.‏\hadithno{4296}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Busr: The Prophet (ﷺ) said: The time between the great war and the conquest of the city (Constantinople) will be six years, and the Dajjal (Antichrist) will come forth in the seventh. Abu Dawud said: This is sounder than the tradition narrated by Isa (bin Yunus)}}
\hadithdefcmd{abudawud}{4297}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا بِشْرُ بْنُ بَكْرٍ، حَدَّثَنَا ابْنُ جَابِرٍ، حَدَّثَنِي أَبُو عَبْدِ السَّلاَمِ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُوشِكُ الأُمَمُ أَنْ تَدَاعَى عَلَيْكُمْ كَمَا تَدَاعَى الأَكَلَةُ إِلَى قَصْعَتِهَا ‏"‏ ‏.‏ فَقَالَ قَائِلٌ وَمِنْ قِلَّةٍ نَحْنُ يَوْمَئِذٍ قَالَ ‏"‏ بَلْ أَنْتُمْ يَوْمَئِذٍ كَثِيرٌ وَلَكِنَّكُمْ غُثَاءٌ كَغُثَاءِ السَّيْلِ وَلَيَنْزِعَنَّ اللَّهُ مِنْ صُدُورِ عَدُوِّكُمُ الْمَهَابَةَ مِنْكُمْ وَلَيَقْذِفَنَّ اللَّهُ فِي قُلُوبِكُمُ الْوَهَنَ ‏"‏ ‏.‏ فَقَالَ قَائِلٌ يَا رَسُولَ اللَّهِ وَمَا الْوَهَنُ قَالَ ‏"‏ حُبُّ الدُّنْيَا وَكَرَاهِيَةُ الْمَوْتِ ‏"‏ ‏.‏\hadithno{4297}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Thawban: The Prophet (ﷺ) said: The people will soon summon one another to attack you as people when eating invite others to share their dish. Someone asked: Will that be because of our small numbers at that time? He replied: No, you will be numerous at that time: but you will be scum and rubbish like that carried down by a torrent, and Allah will take fear of you from the breasts of your enemy and last enervation into your hearts. Someone asked: What is wahn (enervation). Messenger of Allah (ﷺ): He replied: Love of the world and dislike of death}}
\hadithdefcmd{abudawud}{4298}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنَا ابْنُ جَابِرٍ، حَدَّثَنِي زَيْدُ بْنُ أَرْطَاةَ، قَالَ سَمِعْتُ جُبَيْرَ بْنَ نُفَيْرٍ، يُحَدِّثُ عَنْ أَبِي الدَّرْدَاءِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ فُسْطَاطَ الْمُسْلِمِينَ يَوْمَ الْمَلْحَمَةِ بِالْغُوطَةِ إِلَى جَانِبِ مَدِينَةٍ يُقَالُ لَهَا دِمَشْقُ مِنْ خَيْرِ مَدَائِنِ الشَّامِ ‏"‏ ‏.‏\hadithno{4298}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu al-Darda': The Prophet (ﷺ) said: The place of assembly of the Muslims at the time of the war will be in al-Ghutah near a city called Damascus, one of the best cities in Syria}}
\hadithdefcmd{abudawud}{4299}{قَالَ أَبُو دَاوُدَ حُدِّثْتُ عَنِ ابْنِ وَهْبٍ، قَالَ حَدَّثَنِي جَرِيرُ بْنُ حَازِمٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُوشِكُ الْمُسْلِمُونَ أَنْ يُحَاصَرُوا إِلَى الْمَدِينَةِ حَتَّى يَكُونَ أَبْعَدَ مَسَالِحِهِمْ سَلاَحُ ‏"‏ ‏.‏\hadithno{4299}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{Abu Dawud said:Ibn ‘Umar reported the Messenger of Allah (May peace be upon him)As saying: The Muslims will soon be besieged up to Madina so that their most distant frontier outpost will be Salah}}
\hadithdefcmd{abudawud}{4300}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، عَنْ عَنْبَسَةَ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ وَسَلاَحُ قَرِيبٌ مِنْ خَيْبَرَ ‏.‏\hadithno{4300}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu}\hadithtrans{Al-Zuhri said:Salah is near Khaibar}}
\hadithdefcmd{abudawud}{4301}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ، حَدَّثَنَا إِسْمَاعِيلُ، ح وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الْحَسَنُ بْنُ سَوَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا سُلَيْمَانُ بْنُ سُلَيْمٍ، عَنْ يَحْيَى بْنِ جَابِرٍ الطَّائِيِّ، - قَالَ هَارُونُ فِي حَدِيثِهِ - عَنْ عَوْفِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَنْ يَجْمَعَ اللَّهُ عَلَى هَذِهِ الأُمَّةِ سَيْفَيْنِ سَيْفًا مِنْهَا وَسَيْفًا مِنْ عَدُوِّهَا ‏"‏ ‏.‏\hadithno{4301}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Awf ibn Malik: The Prophet (ﷺ) said: Allah will not gather two swords upon this community: Its own sword and the sword of its enemy}}
\hadithdefcmd{abudawud}{4302}{حَدَّثَنَا عِيسَى بْنُ مُحَمَّدٍ الرَّمْلِيُّ، حَدَّثَنَا ضَمْرَةُ، عَنِ السَّيْبَانِيِّ، عَنْ أَبِي سُكَيْنَةَ، - رَجُلٍ مِنَ الْمُحَرَّرِينَ - عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ دَعُوا الْحَبَشَةَ مَا وَدَعُوكُمْ وَاتْرُكُوا التُّرْكَ مَا تَرَكُوكُمْ ‏"‏ ‏.‏\hadithno{4302}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated from Abi Sukainah One of the Companions: The Prophet (ﷺ) said: Let the Abyssinians alone as long as they let you alone, and let the Turks alone as long as they leave you alone}}
\hadithdefcmd{abudawud}{4303}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي الإِسْكَنْدَرَانِيَّ - عَنْ سُهَيْلٍ، - يَعْنِي ابْنَ أَبِي صَالِحٍ - عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يُقَاتِلَ الْمُسْلِمُونَ التُّرْكَ قَوْمًا وُجُوهُهُمْ كَالْمَجَانِّ الْمُطْرَقَةِ يَلْبَسُونَ الشَّعْرَ ‏"‏ ‏.‏\hadithno{4303}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2912)}\hadithtrans{Abu Hurairah reported the Prophet (May peace be upon him) as saying:The last hour will not come before the Muslims fight with the Turks, a people whose faces look as if they were shields covered with skin, and who will wear sandals of hair}}
\hadithdefcmd{abudawud}{4304}{حَدَّثَنَا قُتَيْبَةُ، وَابْنُ السَّرْحِ، وَغَيْرُهُمَا، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، رِوَايَةً - قَالَ ابْنُ السَّرْحِ - أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا نِعَالُهُمُ الشَّعْرُ وَلاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا صِغَارَ الأَعْيُنِ ذُلْفَ الآنُفِ كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطْرَقَةُ ‏"‏ ‏.‏\hadithno{4304}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2929) Sahih Muslim (2912)}\hadithtrans{Abu hurairah reported the Prophet (ﷺ) as saying:The last hour will not come before you fight with a people whose sandals are of hair, and the Last hour will not come before you fight with a people who have small eyes, short noses, and whose faces look as if they were shields covered with skin}}
\hadithdefcmd{abudawud}{4305}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ التِّنِّيسِيُّ، حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا بَشِيرُ بْنُ الْمُهَاجِرِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي حَدِيثِ ‏"‏ يُقَاتِلُكُمْ قَوْمٌ صِغَارُ الأَعْيُنِ ‏"‏ ‏.‏ يَعْنِي التُّرْكَ قَالَ ‏"‏ تَسُوقُونَهُمْ ثَلاَثَ مِرَارٍ حَتَّى تُلْحِقُوهُمْ بِجَزِيرَةِ الْعَرَبِ فَأَمَّا فِي السِّيَاقَةِ الأُولَى فَيَنْجُو مَنْ هَرَبَ مِنْهُمْ وَأَمَّا فِي الثَّانِيَةِ فَيَنْجُو بَعْضٌ وَيَهْلِكُ بَعْضٌ وَأَمَّا فِي الثَّالِثَةِ فَيُصْطَلَمُونَ ‏"‏ ‏.‏ أَوْ كَمَا قَالَ ‏.‏\hadithno{4305}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Buraidah said:In the tradition telling that people with small eyes, i.e. the Turks, will fight against you, the prophet (ﷺ) said: You will drive them off three times till you catch up with them in Arabia. On the first occasion when you drive them off those who fly will be safe, on the second occasion some will be safe and some will perish, but on the third occasion they will be extirpated, or he said words to that effect}}
\hadithdefcmd{abudawud}{4306}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنِي أَبِي، حَدَّثَنَا سَعِيدُ بْنُ جُمْهَانَ، حَدَّثَنَا مُسْلِمُ بْنُ أَبِي بَكْرَةَ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يَنْزِلُ نَاسٌ مِنْ أُمَّتِي بِغَائِطٍ يُسَمُّونَهُ الْبَصْرَةَ عِنْدَ نَهْرٍ يُقَالُ لَهُ دِجْلَةُ يَكُونُ عَلَيْهِ جِسْرٌ يَكْثُرُ أَهْلُهَا وَتَكُونُ مِنْ أَمْصَارِ الْمُهَاجِرِينَ ‏"‏ ‏.‏ قَالَ ابْنُ يَحْيَى قَالَ أَبُو مَعْمَرٍ ‏"‏ وَتَكُونُ مِنْ أَمْصَارِ الْمُسْلِمِينَ فَإِذَا كَانَ فِي آخِرِ الزَّمَانِ جَاءَ بَنُو قَنْطُورَاءَ عِرَاضُ الْوُجُوهِ صِغَارُ الأَعْيُنِ حَتَّى يَنْزِلُوا عَلَى شَطِّ النَّهْرِ فَيَتَفَرَّقُ أَهْلُهَا ثَلاَثَ فِرَقٍ فِرْقَةٌ يَأْخُذُونَ أَذْنَابَ الْبَقَرِ وَالْبَرِّيَّةِ وَهَلَكُوا وَفِرْقَةٌ يَأْخُذُونَ لأَنْفُسِهِمْ وَكَفَرُوا وَفِرْقَةٌ يَجْعَلُونَ ذَرَارِيَّهُمْ خَلْفَ ظُهُورِهِمْ وَيُقَاتِلُونَهُمْ وَهُمُ الشُّهَدَاءُ ‏"‏ ‏.‏\hadithno{4306}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Bakrah: The Messenger of Allah (ﷺ) said: Some of my people will alight on low-lying ground, which they will call al-Basrah, beside a river called Dajjal (the Tigris) over which there is a bridge. Its people will be numerous and it will be one of the capital cities of immigrants (or one of the capital cities of Muslims, according to the version of Ibn Yahya who reported from AbuMa'mar). At the end of time the descendants of Qantura' will come with broad faces and small eyes and alight on the bank of the river. The town's inhabitants will then separate into three sections, one of which will follow cattle and (live in) the desert and perish, another of which will seek security for themselves and perish, but a third will put their children behind their backs and fight the invaders, and they will be the martyrs}}
\hadithdefcmd{abudawud}{4307}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنَا مُوسَى الْحَنَّاطُ، - لاَ أَعْلَمُهُ إِلاَّ ذَكَرَهُ - عَنْ مُوسَى بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُ ‏ "‏ يَا أَنَسُ إِنَّ النَّاسَ يُمَصِّرُونَ أَمْصَارًا وَإِنَّ مِصْرًا مِنْهَا يُقَالُ لَهُ الْبَصْرَةُ أَوِ الْبُصَيْرَةُ فَإِنْ أَنْتَ مَرَرْتَ بِهَا أَوْ دَخَلْتَهَا فَإِيَّاكَ وَسِبَاخَهَا وَكِلاَءَهَا وَسُوقَهَا وَبَابَ أُمَرَائِهَا وَعَلَيْكَ بِضَوَاحِيهَا فَإِنَّهُ يَكُونُ بِهَا خَسْفٌ وَقَذْفٌ وَرَجْفٌ وَقَوْمٌ يَبِيتُونَ يُصْبِحُونَ قِرَدَةً وَخَنَازِيرَ ‏"‏ ‏.‏\hadithno{4307}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: The people will establish cities, Anas, and one of them will be called al-Basrah or al-Busayrah. If you should pass by it or enter it, avoid its salt-marshes, its Kall, its market, and the gate of its commanders, and keep to its environs, for the earth will swallow some people up, pelting rain will fall and earthquakes will take place in it, and there will be people who will spend the night in it and become apes and swine in the morning}}
\hadithdefcmd{abudawud}{4308}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي إِبْرَاهِيمُ بْنُ صَالِحِ بْنِ دِرْهَمٍ، قَالَ سَمِعْتُ أَبِي يَقُولُ، انْطَلَقْنَا حَاجِّينَ فَإِذَا رَجُلٌ فَقَالَ لَنَا إِلَى جَنْبِكُمْ قَرْيَةٌ يُقَالُ لَهَا الأُبُلَّةُ قُلْنَا نَعَمْ ‏.‏ قَالَ مَنْ يَضْمَنُ لِي مِنْكُمْ أَنْ يُصَلِّيَ لِي فِي مَسْجِدِ الْعَشَّارِ رَكْعَتَيْنِ أَوْ أَرْبَعًا وَيَقُولَ هَذِهِ لأَبِي هُرَيْرَةَ سَمِعْتُ خَلِيلِي أَبَا الْقَاسِمِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ يَبْعَثُ مِنْ مَسْجِدِ الْعَشَّارِ يَوْمَ الْقِيَامَةِ شُهَدَاءَ لاَ يَقُومُ مَعَ شُهَدَاءِ بَدْرٍ غَيْرُهُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا الْمَسْجِدُ مِمَّا يَلِي النَّهْرَ ‏.‏\hadithno{4308}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Salih ibn Dirham said:We went on the pilgrimage and met a man who asked us: Is there a town near you called al-Ubullah? We said: Yes. He said: Is there any of you who will undertake to pray two or four rak'ahs on my behalf in the mosque of al-Ashshar, stating "they are on behalf of AbuHurayrah"? He (Abu Hurayrah) said: I heard my friend AbulQasim (ﷺ) say: On the Day of Resurrection Allah will raise martyrs from the mosque of al-Ashshar, who will be the only ones to rise with the martyrs of Badr. Abu Dawud said: This mosque is near the river}}
\hadithdefcmd{abudawud}{4309}{حَدَّثَنَا الْقَاسِمُ بْنُ أَحْمَدَ الْبَغْدَادِيُّ، حَدَّثَنَا أَبُو عَامِرٍ، عَنْ زُهَيْرِ بْنِ مُحَمَّدٍ، عَنْ مُوسَى بْنِ جُبَيْرٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اتْرُكُوا الْحَبَشَةَ مَا تَرَكُوكُمْ فَإِنَّهُ لاَ يَسْتَخْرِجُ كَنْزَ الْكَعْبَةِ إِلاَّ ذُو السُّوَيْقَتَيْنِ مِنَ الْحَبَشَةِ ‏"‏ ‏.‏\hadithno{4309}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: Leave the Abyssinians alone as long as they leave you alone, for it is only the Abyssinian with short legs who will seek to take out the treasure of the Ka'bah}}
\hadithdefcmd{abudawud}{4310}{حَدَّثَنَا مُؤَمَّلُ بْنُ هِشَامٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَبِي حَيَّانَ التَّيْمِيِّ، عَنْ أَبِي زُرْعَةَ، قَالَ جَاءَ نَفَرٌ إِلَى مَرْوَانَ بِالْمَدِينَةِ فَسَمِعُوهُ يُحَدِّثُ فِي الآيَاتِ أَنَّ أَوَّلَهَا الدَّجَّالُ قَالَ فَانْصَرَفْتُ إِلَى عَبْدِ اللَّهِ بْنِ عَمْرٍو فَحَدَّثْتُهُ فَقَالَ عَبْدُ اللَّهِ لَمْ يَقُلْ شَيْئًا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ أَوَّلَ الآيَاتِ خُرُوجًا طُلُوعُ الشَّمْسِ مِنْ مَغْرِبِهَا أَوِ الدَّابَّةُ عَلَى النَّاسِ ضُحًى فَأَيَّتُهُمَا كَانَتْ قَبْلَ صَاحِبَتِهَا فَالأُخْرَى عَلَى أَثَرِهَا ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ وَكَانَ يَقْرَأُ الْكُتُبَ وَأَظُنُّ أَوَّلَهُمَا خُرُوجًا طُلُوعُ الشَّمْسِ مِنْ مَغْرِبِهَا ‏.‏\hadithno{4310}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2941)}\hadithtrans{Abu zur’ah said:A group of people came to Marwan in Medina, and they heard him say that the first of the signs to appear would be the coming forth of the Dajjal (Antichirst). He said: I then went to Abd Allah b. ‘Amr and mentioned it to him. He did not say anything(reliable). I heard the Messenger of Allah (ﷺ) say: The first of the signs to appear will be the rising of the sun in its place of setting and the coming forth of the beast against mankind in the forenoon. Whichever of them comes first will soon be followed by the other. ’Abd Allah who used to read the scriptures (Torah, Gospel) said: I think the first of them will be the rising of the sun in its place of setting}}
\hadithdefcmd{abudawud}{4311}{حَدَّثَنَا مُسَدَّدٌ، وَهَنَّادٌ، - الْمَعْنَى - قَالَ مُسَدَّدٌ حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا فُرَاتٌ الْقَزَّازُ، عَنْ عَامِرِ بْنِ وَاثِلَةَ، - وَقَالَ هَنَّادٌ عَنْ أَبِي الطُّفَيْلِ، - عَنْ حُذَيْفَةَ بْنِ أَسِيدٍ الْغِفَارِيِّ، قَالَ كُنَّا قُعُودًا نَتَحَدَّثُ فِي ظِلِّ غُرْفَةٍ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرْنَا السَّاعَةَ فَارْتَفَعَتْ أَصْوَاتُنَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَنْ تَكُونَ - أَوْ لَنْ تَقُومَ - السَّاعَةُ حَتَّى يَكُونَ قَبْلَهَا عَشْرُ آيَاتٍ طُلُوعُ الشَّمْسِ مِنْ مَغْرِبِهَا وَخُرُوجُ الدَّابَّةِ وَخُرُوجُ يَأْجُوجَ وَمَأْجُوجَ وَالدَّجَّالُ وَعِيسَى ابْنُ مَرْيَمَ وَالدُّخَانُ وَثَلاَثُ خُسُوفٍ خَسْفٌ بِالْمَغْرِبِ وَخَسْفٌ بِالْمَشْرِقِ وَخَسْفٌ بِجَزِيرَةِ الْعَرَبِ وَآخِرُ ذَلِكَ تَخْرُجُ نَارٌ مِنَ الْيَمَنِ مِنْ قَعْرِ عَدَنَ تَسُوقُ النَّاسَ إِلَى الْمَحْشَرِ ‏"‏ ‏.‏\hadithno{4311}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (2901)}\hadithtrans{Hudhaifah b. Asid al-Ansari said :We were sitting in the shade of the chamber of the Messenger of Allah (ﷺ) discussing (something) and when we mentioned the last hour, our voices rose high. The Messenger of Allah (ﷺ) said: The last hour will not come or happen until there appear ten signs before it : the rising of the sun in its place of setting, the coming forth of the beast, the coming forth of Gog and Magog, the Dajjal (Antichrist), (the descent of) Jesus son of Mary, the smoke, and three collapses of the earth: one in the west, one in the east, and one in the Arabian Peninsula. The last of that will be the emergence of a fire from Yemen, from the lowest part of Aden, and drive mankind to their place of assembly}}
\hadithdefcmd{abudawud}{4312}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ الْحَرَّانِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ الْفُضَيْلِ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَطْلُعَ الشَّمْسُ مِنْ مَغْرِبِهَا فَإِذَا طَلَعَتْ وَرَآهَا النَّاسُ آمَنَ مَنْ عَلَيْهَا فَذَاكَ حِينُ ‏\{‏ لاَ يَنْفَعُ نَفْسًا إِيمَانُهَا لَمْ تَكُنْ آمَنَتْ مِنْ قَبْلُ أَوْ كَسَبَتْ فِي إِيمَانِهَا خَيْرًا ‏\}‏ ‏"‏ ‏.‏ الآيَةَ ‏.‏\hadithno{4312}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4635) Sahih Muslim (157)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying:The last hour will not come before rising of the sun in its place of setting. When it rises (there) and the people see it, those who are on it (the earth) will believe. This is the time of which the Qur’anic verse says: “. . .no good will it do to a soul to believe in them then, if it believed not before nor earned righteousness through its faith}}
\hadithdefcmd{abudawud}{4313}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ الْكِنْدِيُّ، حَدَّثَنِي عُقْبَةُ بْنُ خَالِدٍ السَّكُونِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُوشِكُ الْفُرَاتُ أَنْ يَحْسِرَ عَنْ كَنْزٍ مِنْ ذَهَبٍ فَمَنْ حَضَرَهُ فَلاَ يَأْخُذْ مِنْهُ شَيْئًا ‏"‏ ‏.‏\hadithno{4313}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7119) Sahih Muslim (2894)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying:The Euphrates is soon to uncover a treasure of gold, but those who are present must not take any of it}}
\hadithdefcmd{abudawud}{4314}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ الْكِنْدِيُّ، حَدَّثَنِي عُقْبَةُ، - يَعْنِي ابْنَ خَالِدٍ - حَدَّثَنِي عُبَيْدُ اللَّهِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ إِلاَّ أَنَّهُ قَالَ ‏ "‏ يَحْسِرُ عَنْ جَبَلٍ مِنْ ذَهَبٍ ‏"‏ ‏.‏\hadithno{4314}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7119) Sahih Muslim (2894)}\hadithtrans{A similar tradition has also been transmitted by Abu Hurairah from the Prophet (ﷺ) through a different chain of narrators. But this version has:“Uncover a mountain of gold”}}
\hadithdefcmd{abudawud}{4315}{حَدَّثَنَا الْحَسَنُ بْنُ عَمْرٍو، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، قَالَ اجْتَمَعَ حُذَيْفَةُ وَأَبُو مَسْعُودٍ فَقَالَ حُذَيْفَةُ لأَنَا بِمَا مَعَ الدَّجَّالِ أَعْلَمُ مِنْهُ إِنَّ مَعَهُ بَحْرًا مِنْ مَاءٍ وَنَهْرًا مِنْ نَارٍ فَالَّذِي تَرَوْنَ أَنَّهُ نَارٌ مَاءٌ وَالَّذِي تَرَوْنَ أَنَّهُ مَاءٌ نَارٌ فَمَنْ أَدْرَكَ ذَلِكَ مِنْكُمْ فَأَرَادَ الْمَاءَ فَلْيَشْرَبْ مِنَ الَّذِي يَرَى أَنَّهُ نَارٌ فَإِنَّهُ سَيَجِدُهُ مَاءً ‏.‏ قَالَ أَبُو مَسْعُودٍ الْبَدْرِيُّ هَكَذَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏\hadithno{4315}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3450) Sahih Muslim (2934)}\hadithtrans{Hudhaifa and Abu Mas’ud got together and Hudhaifah said:I know best what the Dajjal (Antichrist) will have with him. He will have with him a sea of water and a river of fire, and what you see as fire will be water and what you sea as water will be fire. If any of you who lives up to that time and desires water, he should drink from what he sees as fire, for he will find it water. Abu Mas’ud al-Badri said: I heard the Messenger of Allah (ﷺ) say in this way}}
\hadithdefcmd{abudawud}{4316}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَا بُعِثَ نَبِيٌّ إِلاَّ قَدْ أَنْذَرَ أُمَّتَهُ الدَّجَّالَ الأَعْوَرَ الْكَذَّابَ أَلاَ وَإِنَّهُ أَعْوَرُ وَإِنَّ رَبَّكُمْ لَيْسَ بِأَعْوَرَ وَإِنَّ بَيْنَ عَيْنَيْهِ مَكْتُوبًا كَافِرٌ ‏"‏ ‏.‏\hadithno{4316}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7131) Sahih Muslim (2933)}\hadithtrans{Anas b. Malik reported the Prophet (ﷺ) as saying:No prophet was sent who had not warned his people about the one-eyed. Between his eyes will be written “infidel” (kafir)}}
\hadithdefcmd{abudawud}{4317}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، عَنْ شُعْبَةَ، ك ف ر ‏.‏\hadithno{4317}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2933)}\hadithtrans{Shu’bah said in his version:“the letters k, f, r” (are on his forehead)}}
\hadithdefcmd{abudawud}{4318}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ شُعَيْبِ بْنِ الْحَبْحَابِ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا الْحَدِيثِ قَالَ ‏ "‏ يَقْرَؤُهُ كُلُّ مُسْلِمٍ ‏"‏ ‏.‏\hadithno{4318}\hadithgrade{Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2933)}\hadithtrans{The tradition mentioned above has also been transmitted by Anas b. Malik through a different chain of narrators, This version adds:Every Muslim will read it}}
\hadithdefcmd{abudawud}{4319}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جَرِيرٌ، حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، عَنْ أَبِي الدَّهْمَاءِ، قَالَ سَمِعْتُ عِمْرَانَ بْنَ حُصَيْنٍ، يُحَدِّثُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَمِعَ بِالدَّجَّالِ فَلْيَنْأَ عَنْهُ فَوَاللَّهِ إِنَّ الرَّجُلَ لَيَأْتِيهِ وَهْوَ يَحْسِبُ أَنَّهُ مُؤْمِنٌ فَيَتَّبِعُهُ مِمَّا يُبْعَثُ بِهِ مِنَ الشُّبُهَاتِ أَوْ لِمَا يُبْعَثُ بِهِ مِنَ الشُّبُهَاتِ ‏"‏ ‏.‏ هَكَذَا قَالَ ‏.‏\hadithno{4319}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Imran ibn Husayn: The Prophet (ﷺ) said: Let him who hears of the Dajjal (Antichrist) go far from him for I swear by Allah that a man will come to him thinking he is a believer and follow him because of confused ideas roused in him by him}}
\hadithdefcmd{abudawud}{4320}{حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنِي بَحِيرٌ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ عَمْرِو بْنِ الأَسْوَدِ، عَنْ جُنَادَةَ بْنِ أَبِي أُمَيَّةَ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّهُ حَدَّثَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنِّي قَدْ حَدَّثْتُكُمْ عَنِ الدَّجَّالِ حَتَّى خَشِيتُ أَنْ لاَ تَعْقِلُوا إِنَّ مَسِيحَ الدَّجَّالِ رَجُلٌ قَصِيرٌ أَفْحَجُ جَعْدٌ أَعْوَرُ مَطْمُوسُ الْعَيْنِ لَيْسَ بِنَاتِئَةٍ وَلاَ جَحْرَاءَ فَإِنْ أُلْبِسَ عَلَيْكُمْ فَاعْلَمُوا أَنَّ رَبَّكُمْ لَيْسَ بِأَعْوَرَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ عَمْرُو بْنُ الأَسْوَدِ وَلِيَ الْقَضَاءَ ‏.‏\hadithno{4320}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ubadah ibn as-Samit: The Prophet (ﷺ) said: I have told you so much about the Dajjal (Antichrist) that I am afraid you may not understand. The Antichrist is short, hen-toed, woolly-haired, one-eyed, an eye-sightless, and neither protruding nor deep-seated. If you are confused about him, know that your Lord is not one-eyed. Abu Dawud said: 'Amr bin Al-Aswad was appointed a judge}}
\hadithdefcmd{abudawud}{4321}{حَدَّثَنَا صَفْوَانُ بْنُ صَالِحٍ الدِّمَشْقِيُّ الْمُؤَذِّنُ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا ابْنُ جَابِرٍ، حَدَّثَنَا يَحْيَى بْنُ جَابِرٍ الطَّائِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنِ النَّوَّاسِ بْنِ سَمْعَانَ الْكِلاَبِيِّ، قَالَ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم الدَّجَّالَ فَقَالَ ‏"‏ إِنْ يَخْرُجْ وَأَنَا فِيكُمْ فَأَنَا حَجِيجُهُ دُونَكُمْ وَإِنْ يَخْرُجْ وَلَسْتُ فِيكُمْ فَامْرُؤٌ حَجِيجُ نَفْسِهِ وَاللَّهُ خَلِيفَتِي عَلَى كُلِّ مُسْلِمٍ فَمَنْ أَدْرَكَهُ مِنْكُمْ فَلْيَقْرَأْ عَلَيْهِ فَوَاتِحَ سُورَةِ الْكَهْفِ فَإِنَّهَا جِوَارُكُمْ مِنْ فِتْنَتِهِ ‏"‏ ‏.‏ قُلْنَا وَمَا لُبْثُهُ فِي الأَرْضِ قَالَ ‏"‏ أَرْبَعُونَ يَوْمًا يَوْمٌ كَسَنَةٍ وَيَوْمٌ كَشَهْرٍ وَيَوْمٌ كَجُمُعَةٍ وَسَائِرُ أَيَّامِهِ كَأَيَّامِكُمْ ‏"‏ ‏.‏ فَقُلْنَا يَا رَسُولَ اللَّهِ هَذَا الْيَوْمُ الَّذِي كَسَنَةٍ أَتَكْفِينَا فِيهِ صَلاَةُ يَوْمٍ وَلَيْلَةٍ قَالَ ‏"‏ لاَ اقْدُرُوا لَهُ قَدْرَهُ ثُمَّ يَنْزِلُ عِيسَى ابْنُ مَرْيَمَ عِنْدَ الْمَنَارَةِ الْبَيْضَاءِ شَرْقِيَّ دِمَشْقَ فَيُدْرِكُهُ عِنْدَ بَابِ لُدٍّ فَيَقْتُلُهُ ‏"‏ ‏.‏\hadithno{4321}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2937)}\hadithtrans{Al-nawwas b. Sim’an al-Kilabi said:The Messenger of Allah (ﷺ) mentioned the Dajjal (Antichrist) saying: If he comes forth while I am among you I shall be the one who will dispute with him on your behalf, but if he comes forth when I am not among you, a man must dispute on his own behalf, and Allah will take my place in looking after every Muslim. Those of you who live up to his time should recite over him the opening verses of Surat al – Kahf, for they are your protection from his trial. We asked: How long will he remain on the earth ? He replied : Forty days, one like a year, one like a month, one like a week, and rest of his days like yours. We asked : Messenger of Allah, will one day’s prayer suffice us in this day which will be like a year ? He replied : No, you must make an estimate of its extent. Then Jesus son of Marry will descend at the white minaret to the east of Damascus. He will then catch him up at the date of Ludd and kill him}}
\hadithdefcmd{abudawud}{4322}{حَدَّثَنَا عِيسَى بْنُ مُحَمَّدٍ، حَدَّثَنَا ضَمْرَةُ، عَنِ السَّيْبَانِيِّ، عَنْ عَمْرِو بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي أُمَامَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَذَكَرَ الصَّلَوَاتِ مِثْلَ مَعْنَاهُ ‏.‏\hadithno{4322}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{A similar tradition has been transmitted by Abu Umamah from the prophet (ﷺ) through a different chain of narrators. In this version he mentioned the prayers to the same effect}}
\hadithdefcmd{abudawud}{4323}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ، عَنْ حَدِيثِ أَبِي الدَّرْدَاءِ، يَرْوِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ حَفِظَ عَشْرَ آيَاتٍ مِنْ أَوَّلِ سُورَةِ الْكَهْفِ عُصِمَ مِنْ فِتْنَةِ الدَّجَّالِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَا قَالَ هِشَامٌ الدَّسْتَوَائِيُّ عَنْ قَتَادَةَ إِلاَّ أَنَّهُ قَالَ ‏"‏ مَنْ حَفِظَ مِنْ خَوَاتِيمِ سُورَةِ الْكَهْفِ ‏"‏ ‏.‏ وَقَالَ شُعْبَةُ عَنْ قَتَادَةَ ‏"‏ مِنْ آخِرِ الْكَهْفِ ‏"‏ ‏.‏\hadithno{4323}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (809)}\hadithtrans{Abu al-Darda’ reported the prophet (ﷺ) as saying :If anyone memorizes ten verses from the beginning of surat al-Kahf, he will be protected from the trial of Dajjal (Antichrist). Abu Dawud said: In this way Hashim al-dastawa’I transmitted it from Qatadah, but he said : “If anyone memorizes the closing verses of surat al-Kahf.” Shu’bah narrated from Qatadah the words “from the end of al-Kahf}}
\hadithdefcmd{abudawud}{4324}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، عَنْ قَتَادَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ آدَمَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ بَيْنِي وَبَيْنَهُ نَبِيٌّ - يَعْنِي عِيسَى - وَإِنَّهُ نَازِلٌ فَإِذَا رَأَيْتُمُوهُ فَاعْرِفُوهُ رَجُلٌ مَرْبُوعٌ إِلَى الْحُمْرَةِ وَالْبَيَاضِ بَيْنَ مُمَصَّرَتَيْنِ كَأَنَّ رَأْسَهُ يَقْطُرُ وَإِنْ لَمْ يُصِبْهُ بَلَلٌ فَيُقَاتِلُ النَّاسَ عَلَى الإِسْلاَمِ فَيَدُقُّ الصَّلِيبَ وَيَقْتُلُ الْخِنْزِيرَ وَيَضَعُ الْجِزْيَةَ وَيُهْلِكُ اللَّهُ فِي زَمَانِهِ الْمِلَلَ كُلَّهَا إِلاَّ الإِسْلاَمَ وَيُهْلِكُ الْمَسِيحَ الدَّجَّالَ فَيَمْكُثُ فِي الأَرْضِ أَرْبَعِينَ سَنَةً ثُمَّ يُتَوَفَّى فَيُصَلِّي عَلَيْهِ الْمُسْلِمُونَ ‏"‏ ‏.‏\hadithno{4324}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurayrah: The Prophet (ﷺ) said: There is no prophet between me and him, that is, Jesus (ﷺ). He will descent (to the earth). When you see him, recognise him: a man of medium height, reddish fair, wearing two light yellow garments, looking as if drops were falling down from his head though it will not be wet. He will fight the people for the cause of Islam. He will break the cross, kill swine, and abolish jizyah. Allah will perish all religions except Islam. He will destroy the Antichrist and will live on the earth for forty years and then he will die. The Muslims will pray over him}}
\hadithdefcmd{abudawud}{4325}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا عُثْمَانُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَخَّرَ الْعِشَاءَ الآخِرَةَ ذَاتَ لَيْلَةٍ ثُمَّ خَرَجَ فَقَالَ ‏ "‏ إِنَّهُ حَبَسَنِي حَدِيثٌ كَانَ يُحَدِّثُنِيهِ تَمِيمٌ الدَّارِيُّ عَنْ رَجُلٍ كَانَ فِي جَزِيرَةٍ مِنْ جَزَائِرِ الْبَحْرِ فَإِذَا أَنَا بِامْرَأَةٍ تَجُرُّ شَعْرَهَا قَالَ مَا أَنْتِ قَالَتْ أَنَا الْجَسَّاسَةُ اذْهَبْ إِلَى ذَلِكَ الْقَصْرِ فَأَتَيْتُهُ فَإِذَا رَجُلٌ يَجُرُّ شَعْرَهُ مُسَلْسَلٌ فِي الأَغْلاَلِ يَنْزُو فِيمَا بَيْنَ السَّمَاءِ وَالأَرْضِ فَقُلْتُ مَنْ أَنْتَ قَالَ أَنَا الدَّجَّالُ خَرَجَ نَبِيُّ الأُمِّيِّينَ بَعْدُ قُلْتُ نَعَمْ ‏.‏ قَالَ أَطَاعُوهُ أَمْ عَصَوْهُ قُلْتُ بَلْ أَطَاعُوهُ ‏.‏ قَالَ ذَاكَ خَيْرٌ لَهُمْ ‏"‏ ‏.‏\hadithno{4325}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Fatimah, daughter of Qays: The Messenger of Allah (ﷺ) once delayed the congregational night prayer. He came out and said: The talk of Tamim ad-Dari detained me. He transmitted it to me from a man who was on of of the islands of the sea. All of a sudden he found a woman who was trailing her hair. He asked: Who are you? She said: I am the Jassasah. Go to that castle. So I came to it and found a man who was trailing his hair, chained in iron collars, and leaping between Heaven and Earth. I asked: Who are you? He replied: I am the Dajjal (Antichrist). Has the Prophet of the unlettered people come forth now? I replied: Yes. He said: Have they obeyed him or disobeyed him? I said: No, they have obeyed him. He said: That is better for them}}
\hadithdefcmd{abudawud}{4326}{حَدَّثَنَا حَجَّاجُ بْنُ أَبِي يَعْقُوبَ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ حُسَيْنًا الْمُعَلِّمَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، حَدَّثَنَا عَامِرُ بْنُ شَرَاحِيلَ الشَّعْبِيُّ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، قَالَتْ سَمِعْتُ مُنَادِيَ، رَسُولِ اللَّهِ صلى الله عليه وسلم يُنَادِي أَنَّ الصَّلاَةَ جَامِعَةٌ ‏.‏ فَخَرَجْتُ فَصَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم الصَّلاَةَ جَلَسَ عَلَى الْمِنْبَرِ وَهُوَ يَضْحَكُ قَالَ ‏"‏ لِيَلْزَمْ كُلُّ إِنْسَانٍ مُصَلاَّهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ هَلْ تَدْرُونَ لِمَ جَمَعْتُكُمْ ‏"‏ ‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ إِنِّي مَا جَمَعْتُكُمْ لِرَهْبَةٍ وَلاَ رَغْبَةٍ وَلَكِنْ جَمَعْتُكُمْ أَنَّ تَمِيمًا الدَّارِيَّ كَانَ رَجُلاً نَصْرَانِيًّا فَجَاءَ فَبَايَعَ وَأَسْلَمَ وَحَدَّثَنِي حَدِيثًا وَافَقَ الَّذِي حَدَّثْتُكُمْ عَنِ الدَّجَّالِ حَدَّثَنِي أَنَّهُ رَكِبَ فِي سَفِينَةٍ بَحْرِيَّةٍ مَعَ ثَلاَثِينَ رَجُلاً مِنْ لَخْمٍ وَجُذَامٍ فَلَعِبَ بِهِمُ الْمَوْجُ شَهْرًا فِي الْبَحْرِ وَأَرْفَئُوا إِلَى جَزِيرَةٍ حِينَ مَغْرِبِ الشَّمْسِ فَجَلَسُوا فِي أَقْرَبِ السَّفِينَةِ فَدَخَلُوا الْجَزِيرَةَ فَلَقِيَتْهُمْ دَابَّةٌ أَهْلَبُ كَثِيرَةُ الشَّعْرِ قَالُوا وَيْلَكِ مَا أَنْتِ قَالَتْ أَنَا الْجَسَّاسَةُ انْطَلِقُوا إِلَى هَذَا الرَّجُلِ فِي هَذَا الدَّيْرِ فَإِنَّهُ إِلَى خَبَرِكُمْ بِالأَشْوَاقِ ‏.‏ قَالَ لَمَّا سَمَّتْ لَنَا رَجُلاً فَرِقْنَا مِنْهَا أَنْ تَكُونَ شَيْطَانَةً فَانْطَلَقْنَا سِرَاعًا حَتَّى دَخَلْنَا الدَّيْرَ فَإِذَا فِيهِ أَعْظَمُ إِنْسَانٍ رَأَيْنَاهُ قَطُّ خَلْقًا وَأَشَدُّهُ وَثَاقًا مَجْمُوعَةٌ يَدَاهُ إِلَى عُنُقِهِ ‏"‏ ‏.‏ فَذَكَرَ الْحَدِيثَ وَسَأَلَهُمْ عَنْ نَخْلِ بَيْسَانَ وَعَنْ عَيْنِ زُغَرَ وَعَنِ النَّبِيِّ الأُمِّيِّ قَالَ إِنِّي أَنَا الْمَسِيحُ وَإِنَّهُ يُوشِكُ أَنْ يُؤْذَنَ لِي فِي الْخُرُوجِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَإِنَّهُ فِي بَحْرِ الشَّامِ أَوْ بَحْرِ الْيَمَنِ لاَ بَلْ مِنْ قِبَلِ الْمَشْرِقِ مَا هُوَ ‏"‏ ‏.‏ مَرَّتَيْنِ وَأَوْمَأَ بِيَدِهِ قِبَلَ الْمَشْرِقِ قَالَتْ حَفِظْتُ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{4326}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2942)}\hadithtrans{Fatimah, daughter of Qais, said:I heard the crier of the Messenger of Allah (ﷺ) calling : Assemble for the prayer. I Then came out and prayed along with the Messenger of Allah (ﷺ): When the Messenger of Allah (ﷺ) finished his prayer, he sat on the pulpit laughing, and he said : Everyone should remain where he had said his prayer. He then asked : Do you know why I have assembled you? They said: Allah and His Messenger know best. He (ﷺ) said: I did not call you together fors some alarming news or for something good. Rather, I called you all because Tamim al-Dari, a Christian, who came and accepted Islam, told me something which agrees with what I was telling you about the Dajjal. He told me that he sailed with thirty men of Lakhm and Judham and that they were storm-tossed for a month. They drew near to an island when the sun was setting. They sat in a boat nearest to them and entered the island where they were met by a very hairy beast. They said: Woe to you! What can you be ? It replied : I am the Jassasah. Go to this man in the monastery, for he is anxious to get news of you. He said : When it named a man to us we were afraid of it lest it should be a she-devil. So we went off quickly and entered the monastery, where we found a man with the hugest and strongest frame we had ever seen with his hands chained to his neck. He then narrated the rest of the tradition. He asked them about the palm-trees of Baisan and the spring of Zughar and about the unlettered prophet. He said: I am the messiah (the Antichrist) and will be soon given permission to emerge. And the Prophet (ﷺ) said: He is in the Syrian sea or the Yemeni sea: No, on the contrary, it is towards the east that he is. He said it twice and pointed his hand to the east. She said: I memorized this (tradition) from the Messenger of Allah (ﷺ), and she narrated the tradition}}
\hadithdefcmd{abudawud}{4327}{حَدَّثَنَا مُحَمَّدُ بْنُ صُدْرَانَ، حَدَّثَنَا الْمُعْتَمِرُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ مُجَالِدِ بْنِ سَعِيدٍ، عَنْ عَامِرٍ، قَالَ حَدَّثَتْنِي فَاطِمَةُ بِنْتُ قَيْسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى الظُّهْرَ ثُمَّ صَعِدَ الْمِنْبَرَ وَكَانَ لاَ يَصْعَدُ عَلَيْهِ إِلاَّ يَوْمَ جُمُعَةٍ قَبْلَ يَوْمَئِذٍ ثُمَّ ذَكَرَ هَذِهِ الْقِصَّةَ ‏.‏ قَالَ أَبُو دَاوُدَ وَابْنُ صُدْرَانَ بَصْرِيٌّ غَرِقَ فِي الْبَحْرِ مَعَ ابْنِ مِسْوَرٍ لَمْ يَسْلَمْ مِنْهُمْ غَيْرُهُ ‏.‏\hadithno{4327}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Fatimah, daughter of Qais, said:The prophet (ﷺ) offered the noon prayer and ascended the pulpit. Before this day he did not ascend it except on Friday. He then narrated this story. Abu Dawud said: Ibn Sudran belongs to Basrah. He was drowned in the sea along with Ibn Miswar, and no one could escape except him}}
\hadithdefcmd{abudawud}{4328}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، أَخْبَرَنَا ابْنُ فُضَيْلٍ، عَنِ الْوَلِيدِ بْنِ عَبْدِ اللَّهِ بْنِ جُمَيْعٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ عَلَى الْمِنْبَرِ ‏ "‏ إِنَّهُ بَيْنَمَا أُنَاسٌ يَسِيرُونَ فِي الْبَحْرِ فَنَفِدَ طَعَامُهُمْ فَرُفِعَتْ لَهُمْ جَزِيرَةٌ فَخَرَجُوا يُرِيدُونَ الْخُبْزَ فَلَقِيَتْهُمُ الْجَسَّاسَةُ ‏"‏ ‏.‏ قُلْتُ لأَبِي سَلَمَةَ وَمَا الْجَسَّاسَةُ قَالَ امْرَأَةٌ تَجُرُّ شَعْرَ جِلْدِهَا وَرَأْسِهَا ‏.‏ قَالَتْ فِي هَذَا الْقَصْرِ فَذَكَرَ الْحَدِيثَ وَسَأَلَ عَنْ نَخْلِ بَيْسَانَ وَعَنْ عَيْنِ زُغَرَ قَالَ هُوَ الْمَسِيحُ فَقَالَ لِي ابْنُ أَبِي سَلَمَةَ إِنَّ فِي هَذَا الْحَدِيثِ شَيْئًا مَا حَفِظْتُهُ قَالَ شَهِدَ جَابِرٌ أَنَّهُ هُوَ ابْنُ صَيَّادٍ قُلْتُ فَإِنَّهُ قَدْ مَاتَ ‏.‏ قَالَ وَإِنْ مَاتَ ‏.‏ قُلْتُ فَإِنَّهُ أَسْلَمَ ‏.‏ قَالَ وَإِنْ أَسْلَمَ ‏.‏ قُلْتُ فَإِنَّهُ قَدْ دَخَلَ الْمَدِينَةَ ‏.‏ قَالَ وَإِنْ دَخَلَ الْمَدِينَةَ ‏.‏\hadithno{4328}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) said one day from the pulpit: When some people were sailing in the sea, their food was finished. An island appeared to them. They went out seeking bread. They were met by the Jassasah (the Antichrist's spy). I said to AbuSalamah: What is the Jassasah? He replied: A woman trailing the hair of her skin and of her head. She said: In this castle. He then narrated the rest of the (No. 4311) tradition. He asked about the palm-trees of Baysan and the spring of Zughar. He said: He is the Antichrist. Ibn Salamah said to me: There is something more in this tradition, which I could not remember. He said: Jabir testified that it was he who was Ibn Sayyad. I said: He died. He said: Let him die. I said: He accepted Islam. He said: Let him accept Islam. I said: He entered Medina. He said: Let him enter Medina}}
\hadithdefcmd{abudawud}{4329}{حَدَّثَنَا أَبُو عَاصِمٍ، خُشَيْشُ بْنُ أَصْرَمَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ بِابْنِ صَائِدٍ فِي نَفَرٍ مِنْ أَصْحَابِهِ فِيهِمْ عُمَرُ بْنُ الْخَطَّابِ وَهُوَ يَلْعَبُ مَعَ الْغِلْمَانِ عِنْدَ أُطُمِ بَنِي مَغَالَةَ وَهُوَ غُلاَمٌ فَلَمْ يَشْعُرْ حَتَّى ضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ظَهْرَهُ بِيَدِهِ ثُمَّ قَالَ ‏"‏ أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏"‏ ‏.‏ قَالَ فَنَظَرَ إِلَيْهِ ابْنُ صَيَّادٍ فَقَالَ أَشْهَدُ أَنَّكَ رَسُولُ الأُمِّيِّينَ ‏.‏ ثُمَّ قَالَ ابْنُ صَيَّادٍ لِلنَّبِيِّ صلى الله عليه وسلم أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ آمَنْتُ بِاللَّهِ وَرُسُلِهِ ‏"‏ ‏.‏ ثُمَّ قَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا يَأْتِيكَ ‏"‏ ‏.‏ قَالَ يَأْتِينِي صَادِقٌ وَكَاذِبٌ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ خُلِّطَ عَلَيْكَ الأَمْرُ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي قَدْ خَبَّأْتُ لَكَ خَبِيئَةً ‏"‏ ‏.‏ وَخَبَّأَ لَهُ ‏\{‏ يَوْمَ تَأْتِي السَّمَاءُ بِدُخَانٍ مُبِينٍ ‏\}‏ قَالَ ابْنُ صَيَّادٍ هُوَ الدُّخُّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اخْسَأْ فَلَنْ تَعْدُوَ قَدْرَكَ ‏"‏ ‏.‏ فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ ائْذَنْ لِي فَأَضْرِبَ عُنُقَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ يَكُنْ فَلَنْ تُسَلَّطَ عَلَيْهِ ‏"‏ ‏.‏ يَعْنِي الدَّجَّالَ ‏"‏ وَإِلاَّ يَكُنْ هُوَ فَلاَ خَيْرَ فِي قَتْلِهِ ‏"‏ ‏.‏\hadithno{4329}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3055) Sahih Muslim (2930)}\hadithtrans{Ibn ‘Umar said :The prophet (ﷺ) passed by Ibn Sa’Id along with some of his companions. ‘Umar b. al-Kattab was among them. He was playing with boys near the fortress of Banu Maghalah. He was near the age of puberty (i.e. a boy). Before he was aware, the Messenger of Allah (ﷺ) gave him a pat on the back and said : Do you testify that you are the Messenger of Allah Ibn Sayyad then looked at him and said: I testify that you are the Apostle of Gentiles. Ibn Sayyad then said the prophet (ﷺ) then asked him : What comes to you ? He replied: One who speaks the truth and one who lies come to me. The prophet (may peace upon him) said: You are confused. The Messenger of Allah (may peace upon him) said to him: I have concealed something (in my hand) and he concealed the verse “the day when the sky will bring forth smoke (dukhan) clearly visible Ibn Sayyad said: It is smoke (dukhan) .The Messenger of Allah (ﷺ) said: Away with you, You cannot get farther than your rank. ‘Umar said: “Messenger of Allah, permit me to cut off his head. The Messenger of Allah (ﷺ) said: If he is the one (the Dajjal), you will not be given power over him, and if he is not, you will not do well in killing him}}
\hadithdefcmd{abudawud}{4330}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، قَالَ كَانَ ابْنُ عُمَرَ يَقُولُ وَاللَّهِ مَا أَشُكُّ أَنَّ الْمَسِيحَ الدَّجَّالَ ابْنُ صَيَّادٍ ‏.‏\hadithno{4330}\hadithgrade{Al-Albani: Sahih Isnaad Mauquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Mauquf; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Umar: Nafi' told that Ibn Umar used to say: I swear by Allah that I do not doubt that Antichrist is Ibn Sayyad}}
\hadithdefcmd{abudawud}{4331}{حَدَّثَنَا ابْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، قَالَ رَأَيْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ يَحْلِفُ بِاللَّهِ أَنَّ ابْنَ صَائِدٍ الدَّجَّالُ، فَقُلْتُ تَحْلِفُ بِاللَّهِ فَقَالَ إِنِّي سَمِعْتُ عُمَرَ يَحْلِفُ عَلَى ذَلِكَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمْ يُنْكِرْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4331}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (7355) Sahih Muslim (2929)}\hadithtrans{Muhammad ibn al-Munkadir told that he saw Jabir ibn Abdullah swearing by Allah that Ibn as-Sa'id was the Dajjal (Antichrist). I expressed my surprise by saying:You swear by Allah! He said: I heard Umar swearing to that in the presence of the Messenger of Allah (ﷺ), but the Messenger of Allah (ﷺ) did not make any objection to it}}
\hadithdefcmd{abudawud}{4332}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ مُوسَى - حَدَّثَنَا شَيْبَانُ، عَنِ الأَعْمَشِ، عَنْ سَالِمٍ، عَنْ جَابِرٍ، قَالَ فَقَدْنَا ابْنَ صَيَّادٍ يَوْمَ الْحَرَّةِ ‏.‏\hadithno{4332}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: We saw the last of Ibn Sayyad at the battle of the Harrah}}
\hadithdefcmd{abudawud}{4333}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَخْرُجَ ثَلاَثُونَ دَجَّالُونَ كُلُّهُمْ يَزْعُمُ أَنَّهُ رَسُولُ اللَّهِ ‏"‏ ‏.‏\hadithno{4333}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurayrah: The Prophet (ﷺ) said: The Last Hour will not come before there come forth thirty Dajjals (fraudulents), everyone presuming himself that he is an apostle of Allah}}
\hadithdefcmd{abudawud}{4334}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ عَمْرٍو - عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَخْرُجَ ثَلاَثُونَ كَذَّابًا دَجَّالاً كُلُّهُمْ يَكْذِبُ عَلَى اللَّهِ وَعَلَى رَسُولِهِ ‏"‏ ‏.‏\hadithno{4334}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurayrah: The Prophet (ﷺ) said: The Last Hour will not come before there come forth thirty liar Dajjals (fraudulents) lying on Allah and His Apostle}}
\hadithdefcmd{abudawud}{4335}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، عَنْ جَرِيرٍ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، قَالَ قَالَ عَبِيدَةُ السَّلْمَانِيُّ بِهَذَا الْخَبَرِ قَالَ فَذَكَرَ نَحْوَهُ فَقُلْتُ لَهُ أَتَرَى هَذَا مِنْهُمْ - يَعْنِي الْمُخْتَارَ - فَقَالَ عَبِيدَةُ أَمَا إِنَّهُ مِنَ الرُّءُوسِ ‏.‏\hadithno{4335}\hadithgrade{Al-Albani: Daif Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Daif Maqtu; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{A similar tradition has also been transmitted by Ibrahim (al-Nakha’l) through a different chain if narrators. I (Ibrahim) said to ‘Ubaidat al-Salmant :Do you think that his one of them, that is al-Mukhtar (al-Thaqaff)? He said : He is from the leaders}}
\hadithdefcmd{abudawud}{4336}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا يُونُسُ بْنُ رَاشِدٍ، عَنْ عَلِيِّ بْنِ بَذِيمَةَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ أَوَّلَ مَا دَخَلَ النَّقْصُ عَلَى بَنِي إِسْرَائِيلَ كَانَ الرَّجُلُ يَلْقَى الرَّجُلَ فَيَقُولُ يَا هَذَا اتَّقِ اللَّهِ وَدَعْ مَا تَصْنَعُ فَإِنَّهُ لاَ يَحِلُّ لَكَ ثُمَّ يَلْقَاهُ مِنَ الْغَدِ فَلاَ يَمْنَعُهُ ذَلِكَ أَنْ يَكُونَ أَكِيلَهُ وَشَرِيبَهُ وَقَعِيدَهُ فَلَمَّا فَعَلُوا ذَلِكَ ضَرَبَ اللَّهُ قُلُوبَ بَعْضِهِمْ بِبَعْضٍ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏\{‏ لُعِنَ الَّذِينَ كَفَرُوا مِنْ بَنِي إِسْرَائِيلَ عَلَى لِسَانِ دَاوُدَ وَعِيسَى ابْنِ مَرْيَمَ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ فَاسِقُونَ ‏\}‏ ثُمَّ قَالَ ‏"‏ كَلاَّ وَاللَّهِ لَتَأْمُرُنَّ بِالْمَعْرُوفِ وَلَتَنْهَوُنَّ عَنِ الْمُنْكَرِ وَلَتَأْخُذُنَّ عَلَى يَدَىِ الظَّالِمِ وَلَتَأْطُرُنَّهُ عَلَى الْحَقِّ أَطْرًا وَلَتَقْصُرُنَّهُ عَلَى الْحَقِّ قَصْرًا ‏"‏ ‏.‏\hadithno{4336}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Messenger of Allah (ﷺ) said: The first defect that permeated Banu Isra'il was that a man (of them) met another man and said: O so-and-so, fear Allah, and abandon what you are doing, for it is not lawful for you. He then met him the next day and that did not prevent him from eating with him, drinking with him and sitting with him. When they did so. Allah mingled their hearts with each other. He then recited the verse: "curses were pronounced on those among the children of Isra'il who rejected Faith, by the tongue of David and of Jesus the son of Mary"...up to "wrongdoers". He then said: By no means, I swear by Allah, you must enjoin what is good and prohibit what is evil, prevent the wrongdoer, bend him into conformity with what is right, and restrict him to what is right}}
\hadithdefcmd{abudawud}{4337}{حَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، حَدَّثَنَا أَبُو شِهَابٍ الْحَنَّاطُ، عَنِ الْعَلاَءِ بْنِ الْمُسَيَّبِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَالِمٍ، عَنْ أَبِي عُبَيْدَةَ، عَنِ ابْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ زَادَ ‏ "‏ أَوْ لَيَضْرِبَنَّ اللَّهُ بِقُلُوبِ بَعْضِكُمْ عَلَى بَعْضٍ ثُمَّ لَيَلْعَنَنَّكُمْ كَمَا لَعَنَهُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الْمُحَارِبِيُّ عَنِ الْعَلاَءِ بْنِ الْمُسَيَّبِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ مُرَّةَ عَنْ سَالِمٍ الأَفْطَسِ عَنْ أَبِي عُبَيْدَةَ عَنْ عَبْدِ اللَّهِ رَوَاهُ خَالِدٌ الطَّحَّانُ عَنِ الْعَلاَءِ عَنْ عَمْرِو بْنِ مُرَّةَ عَنْ أَبِي عُبَيْدَةَ ‏.‏\hadithno{4337}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{A similar tradition (to the No. 4322) has also been transmitted by Ibn Mas'ud through a different chain of narrators to the same effect. This version adds:"Or Allah will mingle your hearts together and curse you as He cursed them." Abu Dawud said: This tradition has been transmitted by al-Muharibi, from al-'Ala bin al-Musayyab, from 'Abd Allah bin 'Amr bin Murrah, from Salim al-Aftas, from Abu Ubaidah, from 'Abd Allah; and it is been transmitted by Khalid al-Tahhan, from al-'Ala, from 'Amr bin Murrah from Abu 'Ubaidah}}
\hadithdefcmd{abudawud}{4338}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، ح وَحَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا هُشَيْمٌ، - الْمَعْنَى - عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، قَالَ قَالَ أَبُو بَكْرٍ بَعْدَ أَنْ حَمِدَ اللَّهَ، وَأَثْنَى، عَلَيْهِ يَا أَيُّهَا النَّاسُ إِنَّكُمْ تَقْرَءُونَ هَذِهِ الآيَةَ وَتَضَعُونَهَا عَلَى غَيْرِ مَوَاضِعِهَا ‏\{‏ عَلَيْكُمْ أَنْفُسَكُمْ لاَ يَضُرُّكُمْ مَنْ ضَلَّ إِذَا اهْتَدَيْتُمْ ‏\}‏ قَالَ عَنْ خَالِدٍ وَإِنَّا سَمِعْنَا النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ النَّاسَ إِذَا رَأَوُا الظَّالِمَ فَلَمْ يَأْخُذُوا عَلَى يَدَيْهِ أَوْشَكَ أَنْ يَعُمَّهُمُ اللَّهُ بِعِقَابٍ ‏"‏ ‏.‏ وَقَالَ عَمْرٌو عَنْ هُشَيْمٍ وَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَا مِنْ قَوْمٍ يُعْمَلُ فِيهِمْ بِالْمَعَاصِي ثُمَّ يَقْدِرُونَ عَلَى أَنْ يُغَيِّرُوا ثُمَّ لاَ يُغَيِّرُوا إِلاَّ يُوشِكُ أَنْ يَعُمَّهُمُ اللَّهُ مِنْهُ بِعِقَابٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ كَمَا قَالَ خَالِدٌ أَبُو أُسَامَةَ وَجَمَاعَةٌ ‏.‏ وَقَالَ شُعْبَةُ فِيهِ ‏"‏ مَا مِنْ قَوْمٍ يُعْمَلُ فِيهِمْ بِالْمَعَاصِي هُمْ أَكْثَرُ مِمَّنْ يَعْمَلُهُ ‏"‏ ‏.‏\hadithno{4338}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Bakr: You people recite this verse "You who believe, care for yourselves; he who goes astray cannot harm you when you are rightly-guided," and put it in its improper place. Khalid's version has: We heard the Prophet (ﷺ) say: When the people see a wrongdoer and do not prevent him, Allah will soon punish them all. Amr ibn Hushaym's version has: I heard the Messenger of Allah (ﷺ) say: If acts of disobedience are done among any people and do not change them though the are able to do so, Allah will soon punish them all. Adu Dawud said: This tradition has also been transmitted by Abu Usamah and a group transmitters similar to the version narrated by Khalid. The version of Shu'bah has: "If acts of obedience are done among any people who are more numerous than those who do them}}
\hadithdefcmd{abudawud}{4339}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا أَبُو إِسْحَاقَ، - أَظُنُّهُ - عَنِ ابْنِ جَرِيرٍ، عَنْ جَرِيرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ رَجُلٍ يَكُونُ فِي قَوْمٍ يُعْمَلُ فِيهِمْ بِالْمَعَاصِي يَقْدِرُونَ عَلَى أَنْ يُغَيِّرُوا عَلَيْهِ فَلاَ يُغَيِّرُوا إِلاَّ أَصَابَهُمُ اللَّهُ بِعَذَابٍ مِنْ قَبْلِ أَنْ يَمُوتُوا ‏"‏ ‏.‏\hadithno{4339}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: If any man is among a people in whose midst he does acts of disobedience, and, though they are able to make him change (his acts), they do not change, Allah will smite them with punishment before they die}}
\hadithdefcmd{abudawud}{4340}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، وَهَنَّادُ بْنُ السَّرِيِّ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِسْمَاعِيلَ بْنِ رَجَاءٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ، وَعَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ رَأَى مُنْكَرًا فَاسْتَطَاعَ أَنْ يُغَيِّرَهُ بِيَدِهِ فَلْيُغَيِّرْهُ بِيَدِهِ ‏"‏ ‏.‏ وَقَطَعَ هَنَّادٌ بَقِيَّةَ الْحَدِيثِ - وَفَّاهُ ابْنُ الْعَلاَءِ - ‏"‏ فَإِنْ لَمْ يَسْتَطِعْ فَبِلِسَانِهِ فَإِنْ لَمْ يَسْتَطِعْ بِلِسَانِهِ فَبِقَلْبِهِ وَذَلِكَ أَضْعَفُ الإِيمَانِ ‏"‏ ‏.‏\hadithno{4340}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (49)}\hadithtrans{Abu sa’Id al-Khudri said:I head the Messenger of Allah (ﷺ) say: If any one you sees something objectionable, he should change it with his hand if he can change it with his hand. (The narrator Hammad broke the rest of the tradition which was completed by Ibn al-‘Ala’.) But if he cannot (do so), he should do it with his tongue, and if he cannot (do so with) his tongue he should do it in his heart, that being the weakest form of faith}}
\hadithdefcmd{abudawud}{4341}{حَدَّثَنَا أَبُو الرَّبِيعِ، سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ عُتْبَةَ بْنِ أَبِي حَكِيمٍ، قَالَ حَدَّثَنِي عَمْرُو بْنُ جَارِيَةَ اللَّخْمِيُّ، حَدَّثَنِي أَبُو أُمَيَّةَ الشَّعْبَانِيُّ، قَالَ سَأَلْتُ أَبَا ثَعْلَبَةَ الْخُشَنِيَّ فَقُلْتُ يَا أَبَا ثَعْلَبَةَ كَيْفَ تَقُولُ فِي هَذِهِ الآيَةِ ‏\{‏ عَلَيْكُمْ أَنْفُسَكُمْ ‏\}‏ قَالَ أَمَا وَاللَّهِ لَقَدْ سَأَلْتَ عَنْهَا خَبِيرًا سَأَلْتُ عَنْهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ بَلِ ائْتَمِرُوا بِالْمَعْرُوفِ وَتَنَاهَوْا عَنِ الْمُنْكَرِ حَتَّى إِذَا رَأَيْتَ شُحًّا مُطَاعًا وَهَوًى مُتَّبَعًا وَدُنْيَا مُؤْثَرَةً وَإِعْجَابَ كُلِّ ذِي رَأْىٍ بِرَأْيِهِ فَعَلَيْكَ - يَعْنِي بِنَفْسِكَ - وَدَعْ عَنْكَ الْعَوَامَّ فَإِنَّ مِنْ وَرَائِكُمْ أَيَّامَ الصَّبْرِ الصَّبْرُ فِيهِ مِثْلُ قَبْضٍ عَلَى الْجَمْرِ لِلْعَامِلِ فِيهِمْ مِثْلُ أَجْرِ خَمْسِينَ رَجُلاً يَعْمَلُونَ مِثْلَ عَمَلِهِ ‏"‏ ‏.‏ وَزَادَنِي غَيْرُهُ قَالَ يَا رَسُولَ اللَّهِ أَجْرُ خَمْسِينَ مِنْهُمْ قَالَ ‏"‏ أَجْرُ خَمْسِينَ مِنْكُمْ ‏"‏ ‏.‏\hadithno{4341}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Umayyah ash-Sha'bani said:I asked AbuTha'labah al-Khushani: What is your opinion about the verse "Care for yourselves". He said: I swear by Allah, I asked the one who was well informed about it; I asked the Messenger of Allah (ﷺ) about it. He said: No, enjoin one another to do what is good and forbid one another to do what is evil. But when you see niggardliness being obeyed, passion being followed, worldly interests being preferred, everyone being charmed with his opinion, then care for yourself, and leave alone what people in general are doing; for ahead of you are days which will require endurance, in which showing endurance will be like grasping live coals. The one who acts rightly during that period will have the reward of fifty men who act as he does. Another version has: He said (The hearers asked:) Messenger of Allah, the reward of fifty of them? He replied: The reward of fifty of you}}
\hadithdefcmd{abudawud}{4342}{حَدَّثَنَا الْقَعْنَبِيُّ، أَنَّ عَبْدَ الْعَزِيزِ بْنَ أَبِي حَازِمٍ، حَدَّثَهُمْ عَنْ أَبِيهِ، عَنْ عُمَارَةَ بْنِ عَمْرٍو، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ كَيْفَ بِكُمْ وَبِزَمَانٍ ‏"‏ ‏.‏ أَوْ ‏"‏ يُوشِكُ أَنْ يَأْتِيَ زَمَانٌ يُغَرْبَلُ النَّاسُ فِيهِ غَرْبَلَةً تَبْقَى حُثَالَةٌ مِنَ النَّاسِ قَدْ مَرِجَتْ عُهُودُهُمْ وَأَمَانَاتُهُمْ وَاخْتَلَفُوا فَكَانُوا هَكَذَا ‏"‏ ‏.‏ وَشَبَّكَ بَيْنَ أَصَابِعِهِ فَقَالُوا وَكَيْفَ بِنَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ تَأْخُذُونَ مَا تَعْرِفُونَ وَتَذَرُونَ مَا تُنْكِرُونَ وَتُقْبِلُونَ عَلَى أَمْرِ خَاصَّتِكُمْ وَتَذَرُونَ أَمْرَ عَامَّتِكُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَكَذَا رُوِيَ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ وَجْهٍ ‏.‏\hadithno{4342}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: How will you do when that time will come? Or he said: A time will soon come when the people are sifted and only dregs of mankind survive and their covenants and guarantees have been impaired and they have disagreed among themselves and become thus, interwining his fingers. They asked: What do you order us to do, Messenger of Allah? He replied: Accept what you approve, abandon what you disapprove, attend to your own affairs and leave alone the affairs of the generality. Abu dawud said: A similar tradition has been transmitted by 'Abd Allah bin 'Amr from the Prophet (ﷺ) through different chain}}
\hadithdefcmd{abudawud}{4343}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ هِلاَلِ بْنِ خَبَّابٍ أَبِي الْعَلاَءِ، قَالَ حَدَّثَنِي عِكْرِمَةُ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ الْعَاصِ، قَالَ بَيْنَمَا نَحْنُ حَوْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ ذَكَرَ الْفِتْنَةَ فَقَالَ ‏"‏ إِذَا رَأَيْتُمُ النَّاسَ قَدْ مَرِجَتْ عُهُودُهُمْ وَخَفَّتْ أَمَانَاتُهُمْ وَكَانُوا هَكَذَا ‏"‏ ‏.‏ وَشَبَّكَ بَيْنَ أَصَابِعِهِ قَالَ فَقُمْتُ إِلَيْهِ فَقُلْتُ كَيْفَ أَفْعَلُ عِنْدَ ذَلِكَ جَعَلَنِي اللَّهُ فِدَاكَ قَالَ ‏"‏ الْزَمْ بَيْتَكَ وَامْلِكْ عَلَيْكَ لِسَانَكَ وَخُذْ بِمَا تَعْرِفُ وَدَعْ مَا تُنْكِرُ وَعَلَيْكَ بِأَمْرِ خَاصَّةِ نَفْسِكَ وَدَعْ عَنْكَ أَمْرَ الْعَامَّةِ ‏"‏ ‏.‏\hadithno{4343}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: When we were around the Messenger of Allah (ﷺ), he mentioned the period of commotion (fitnah) saying: When you see the people that their covenants have been impaired, (the fulfilling of) the guarantees becomes rare, and they become thus (interwining his fingers). I then got up and said: What should I do at that time, may Allah make me ransom for you? He replied: Keep to your house, control your tongue, accept what you approve, abandon what you disapprove, attend to your own affairs, and leave alone the affairs of the generality}}
\hadithdefcmd{abudawud}{4344}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَادَةَ الْوَاسِطِيُّ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ هَارُونَ - أَخْبَرَنَا إِسْرَائِيلُ، حَدَّثَنَا مُحَمَّدُ بْنُ جُحَادَةَ، عَنْ عَطِيَّةَ الْعَوْفِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَفْضَلُ الْجِهَادِ كَلِمَةُ عَدْلٍ عِنْدَ سُلْطَانٍ جَائِرٍ ‏"‏ ‏.‏ أَوْ ‏"‏ أَمِيرٍ جَائِرٍ ‏"‏ ‏.‏\hadithno{4344}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) said: The best fighting (jihad) in the path of Allah is (to speak) a word of justice to an oppressive ruler}}
\hadithdefcmd{abudawud}{4345}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَخْبَرَنَا أَبُو بَكْرٍ، حَدَّثَنَا مُغِيرَةُ بْنُ زِيَادٍ الْمَوْصِلِيُّ، عَنْ عَدِيِّ بْنِ عَدِيٍّ، عَنِ الْعُرْسِ بْنِ عَمِيرَةَ الْكِنْدِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا عُمِلَتِ الْخَطِيئَةُ فِي الأَرْضِ كَانَ مَنْ شَهِدَهَا فَكَرِهَهَا ‏"‏ ‏.‏ وَقَالَ مَرَّةً ‏"‏ أَنْكَرَهَا ‏"‏ ‏.‏ ‏"‏ كَمَنْ غَابَ عَنْهَا وَمَنْ غَابَ عَنْهَا فَرَضِيَهَا كَانَ كَمَنْ شَهِدَهَا ‏"‏ ‏.‏\hadithno{4345}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Al-'Urs bin 'Amirat al-Kindi: The Prophet (ﷺ) said: When sin is done in the earth, he who sees it and disapproves of it will be taken like one who was not present, but he who is not present and approves of it will be like him who sees}}
\hadithdefcmd{abudawud}{4346}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو شِهَابٍ، عَنْ مُغِيرَةَ بْنِ زِيَادٍ، عَنْ عَدِيِّ بْنِ عَدِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ قَالَ ‏ "‏ مَنْ شَهِدَهَا فَكَرِهَهَا كَانَ كَمَنْ غَابَ عَنْهَا ‏"‏ ‏.‏\hadithno{4346}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{A similar tradition has also been transmitted by ‘Adl from the prophet (ﷺ) though a different chain of narrators. This version has :He who sees it and disapproves of it will be like him who was not present}}
\hadithdefcmd{abudawud}{4347}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَحَفْصُ بْنُ عُمَرَ، قَالاَ حَدَّثَنَا شُعْبَةُ، - وَهَذَا لَفْظُهُ - عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي الْبَخْتَرِيِّ، قَالَ أَخْبَرَنِي مَنْ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ وَقَالَ سُلَيْمَانُ حَدَّثَنِي رَجُلٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَنْ يَهْلِكَ النَّاسُ حَتَّى يَعْذِرُوا أَوْ يُعْذِرُوا مِنْ أَنْفُسِهِمْ ‏"‏ ‏.‏\hadithno{4347}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{A man from among the companions of the prophet (ﷺ) reported him as saying:The people will not perish until their sins and faults become abundant, and there remains no excuse for them}}
\hadithdefcmd{abudawud}{4348}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، وَأَبُو بَكْرِ بْنُ سُلَيْمَانَ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ صَلاَةَ الْعِشَاءِ فِي آخِرِ حَيَاتِهِ فَلَمَّا سَلَّمَ قَامَ فَقَالَ ‏ "‏ أَرَأَيْتُمْ لَيْلَتَكُمْ هَذِهِ فَإِنَّ عَلَى رَأْسِ مِائَةِ سَنَةٍ مِنْهَا لاَ يَبْقَى مِمَّنْ هُوَ عَلَى ظَهْرِ الأَرْضِ أَحَدٌ ‏"‏ ‏.‏ قَالَ ابْنُ عُمَرَ فَوَهَلَ النَّاسُ فِي مَقَالَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم تِلْكَ فِيمَا يَتَحَدَّثُونَ عَنْ هَذِهِ الأَحَادِيثِ عَنْ مِائَةِ سَنَةٍ وَإِنَّمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يَبْقَى مِمَّنْ هُوَ الْيَوْمَ عَلَى ظَهْرِ الأَرْضِ يُرِيدُ أَنْ يَنْخَرِمَ ذَلِكَ الْقَرْنُ ‏.‏\hadithno{4348}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2537)}\hadithtrans{‘Abd Allah b. ‘Umar said :The Messenger of Allah (ﷺ) led us in the night prayer one night towards the end of his life. When he uttered the salutation, he got up and said : Have you seen this night of yours ? No one of those who are on the surface of the earth will survive at the ends of one hundred years. Ibn ‘Umar said: The people fell into fallacy by this statement of the Messenger of Allah (ﷺ) about the traditions they used to narrate concerning one hundred years. The Messenger of Allah (ﷺ) said: No one of those who are present today on the surface of the earth will survive, meaning when that century comes to and end}}
\hadithdefcmd{abudawud}{4349}{حَدَّثَنَا مُوسَى بْنُ سَهْلٍ، حَدَّثَنَا حَجَّاجُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَنْ يَعْجِزَ اللَّهُ هَذِهِ الأُمَّةَ مِنْ نِصْفِ يَوْمٍ ‏"‏ ‏.‏\hadithno{4349}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Tha'labat al-Khushani: The Prophet (ﷺ) said: Allah will not fail to detain this community for less than half a day}}
\hadithdefcmd{abudawud}{4350}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنِي صَفْوَانُ، عَنْ شُرَيْحِ بْنِ عُبَيْدٍ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنِّي لأَرْجُو أَنْ لاَ تُعْجِزَ أُمَّتِي عِنْدَ رَبِّهَا أَنْ يُؤَخِّرَهُمْ نِصْفَ يَوْمٍ ‏"‏ ‏.‏ قِيلَ لِسَعْدٍ وَكَمْ نِصْفُ يَوْمٍ قَالَ خَمْسُمِائَةِ سَنَةٍ ‏.‏\hadithno{4350}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sa'd ibn AbuWaqqas: The Prophet (ﷺ) said: I hope my community will not fail to maintain their position in the sight of their Lord if He delays them half a day. Sa'd was asked: How long is half a day? He said: It is five hundred years}}
